pub fn inject_scheduler(scheduler: &'static dyn Scheduler<Task>)Expand description
Injects a custom implementation of task scheduler into OSTD.
This function can only be called once and must be called
during the initialization phase of kernel,
before any Task-related APIs are invoked.
Panics
This function panics if a scheduler has already been injected, either explicitly via a previous call to this function or implicitly via the lazy default FIFO scheduler.